@@ -1,3 +1,9 @@
+<?php
+/**
+ * @file
+ * Default theme implementation to display a help popup.
+ */
+?>
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language ?>" lang="<?php print $language->language ?>" dir="<?php print $language->dir ?>">
@@ -9,7 +15,7 @@
   <?php print $scripts; ?>
   <script type="text/javascript"><?php /* Needed to avoid Flash of Unstyled Content in IE */ ?> </script>
 </head>
-<body>
+<body class="advanced-help-popup-body">
   <div id="page">
     <div id="header">
       <?php if (!empty($search_box)): ?>
